/***********************************************************************************************************************************
Test Assert Macros and Routines
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Test Run
***********************************************************************************************************************************/
static void
testRun(void)
{
    FUNCTION_HARNESS_VOID();

    // *****************************************************************************************************************************
    if (testBegin("ASSERT()"))
    {
        TEST_RESULT_VOID(ASSERT(true), "assert true");
        TEST_ERROR(ASSERT(false || false), AssertError, "assertion 'false || false' failed");
    }

    FUNCTION_HARNESS_RETURN_VOID();
}
